from aiges.dto import Response, ResponseData, DataListNode, DataListCls

"""personal param"""
model_name = 'bge_visualized_m3'
pretrain_model_name = '/home/atpdata/models_hub/bigmodels/for_atp/bge_visualized_m3/'
token_path = '/home/atpdata/models_hub/bigmodels/for_atp/bge_visualized_m3/'
zip_path = '/home/finetuned_models/my_chinese_alpaca2_model//adapter.zip'
stream = 0
finetune_type = 'lora'
infer_type = 'base'
""""""

import sys
print(sys.path)

import importlib
module_path = f'ailab.inference_wrapper.huggingface.transformers.embedding.wrapper'
wrapper_module = importlib.import_module(module_path)
Wrapper = getattr(wrapper_module, 'Wrapper')
wrapper = Wrapper()

def get_messages(image_path, text):
    from PIL import Image
    import base64,io
    image = Image.open(image_path)
    byte_data = io.BytesIO()
    image.save(byte_data, format='JPEG')
    # 将字节流转换为Base64编码
    image_base64 = base64.b64encode(byte_data.getvalue()).decode('utf-8')
    message = {
        "messages": [ 
            {
                "role": "user",
                "content": text,
                "content_type":"text"
            },
            {
                "role": "user",
                "content": image_base64,
                "content_type":"image"
            }
        ]
    }
    import json
    return json.dumps(message)

def Init():
    import os
    os.environ['PRETRAINED_MODEL_NAME'] = model_name
    os.environ['FULL_MODEL_PATH'] = pretrain_model_name
    os.environ['TOKENIZER_PATH'] = token_path
    os.environ['FINETUNE_TYPE'] = finetune_type
    os.environ['INFER_TYPE'] = infer_type
    config = {}
    if stream:
        config['common.lic'] = 1
    wrapper.wrapperInit(config)

def LoadRes(key):
    zip_file_path = zip_path
    with open(zip_file_path, 'rb') as zip_file:
        # 读取压缩包的二进制数据
        zip_data = zip_file.read()
        # 计算数据长度
        zip_data_length = len(zip_data)

    list_node = DataListNode()
    list_node.key = str(key)
    list_node.data = zip_data
    list_node.len = zip_data_length

    req_data = DataListCls()
    req_data.list.append(list_node)
    wrapper.wrapperLoadRes(req_data, key)

def Once(key, image_path, text):
    http_node = DataListNode()
    http_node.key = 'messages'
    text_data = get_messages(image_path,text).encode('utf-8')
    http_node.data = text_data 
    http_data = DataListCls()
    http_data.list.append(http_node)

    params = {
        "patch_id":key,
        "temperature":'0.95',
        "top_k":'60',
        "max_tokens":'512'
    }
    wrapper.wrapperOnceExec(params, http_data)

def UnloadRes(key):
    wrapper.wrapperUnloadRes(key)

def StreamCreate(patch_id):
    params = {
        "patch_id":patch_id,
        "temperature":'0.95',
        "top_k":'60',
        "max_tokens":'512'
    }
    s = wrapper.wrapperCreate(params, 'presid',patch_id)
    return s.handle

def StreamWrite(handle,image_path,text):
    http_node = DataListNode()
    http_node.key = 'messages'
    text_data = get_messages(image_path,text).encode('utf-8')
    http_node.data = text_data 
    http_data = DataListCls()
    http_data.list.append(http_node)

    wrapper.wrapperWrite(handle,http_data)

def StreamDestroy(handle):
    wrapper.wrapperDestroy(handle)

if __name__ == '__main__' :
    Init()
    #LoadRes('1')
    path = '/opt/ailab_sdk/src/ailab/inference_wrapper/huggingface/transformers/multimodal/visual_question_answering/wrapper/cat.jpg'
    #query = "{\"query\": \"合肥动物园在哪里？\",\"texts\": [{\"id\": 1,\"content\": \"动物园里有什么\"},{\"id\": 2,\"content\": \"合肥市动物园坐落于大蜀山西\"},{\"id\": 3,\"content\": \"动物园有大象和小狗\"}]}"
    query = "这是一只猫"
    Once('0', path, query)
    #UnloadRes('1')


